@@ -114,7 +114,7 @@ class Expression:
         the specified types.
 
         Args:
-            expression_types (type): the expression type to match.
+            expression_types (type): the expression type(s) to match.
 
         Returns:
             the node which matches the criteria or None if no node matching
@@ -128,7 +128,7 @@ class Expression:
         yields those that match at least one of the specified expression types.
 
         Args:
-            expression_types (type): the expression type to match.
+            expression_types (type): the expression type(s) to match.
 
         Returns:
             the generator object.
@@ -138,11 +138,27 @@ class Expression:
                 yield expression
 
     def find_ancestor(self, *expression_types):
+        """
+        Returns a nearest parent matching expression_types.
+
+        Args:
+            expression_types (type): the expression type(s) to match.
+
+        Returns:
+            the parent node
+        """
         ancestor = self.parent
         while ancestor and not isinstance(ancestor, expression_types):
             ancestor = ancestor.parent
         return ancestor
 
+    @property
+    def parent_select(self):
+        """
+        Returns the parent select statement.
+        """
+        return self.find_ancestor(Select)
+
     def walk(self, bfs=True):
         """
         Returns a generator object which visits all nodes in this tree.
@@ -305,7 +321,7 @@ class Expression:
         )
         return new_node
 
-    def replace(self, *expressions):
+    def replace(self, expression):
         """
         Swap out this expression with a new expression.
 
@@ -313,19 +329,24 @@ class Expression:
 
             >>> tree = Select().select("x").from_("tbl")
             >>> tree.find(Column).replace(Column(this="y"))
+            (COLUMN this: y)
             >>> tree.sql()
             'SELECT y FROM tbl'
 
         Args:
             expression (Expression): new node
+
+        Returns :
+            the new expression or expressions
         """
         if not self.parent:
-            return
+            return expression
 
         parent = self.parent
         self.parent = None
 
-        replace_children(parent, lambda child: expressions if child is self else child)
+        replace_children(parent, lambda child: expression if child is self else child)
+        return expression
 
     def assert_is(self, type_):
         """
@@ -598,6 +619,10 @@ class Join(Expression):
     def kind(self):
         return self.text("kind").upper()
 
+    @property
+    def side(self):
+        return self.text("side").upper()
+
     def on(self, *expressions, append=True, dialect=None, parser_opts=None, copy=True):
         """
         Append to or set the ON expressions.
@@ -1321,6 +1346,14 @@ class Star(Expression):
         return "*"
 
 
+class StarExcept(Expression):
+    arg_types = {"this": True, "expressions": True}
+
+
+class StarReplace(Expression):
+    arg_types = {"this": True, "expressions": True}
+
+
 class Null(Condition):
     arg_types = {}
 
@@ -1676,10 +1709,22 @@ class ArrayAgg(AggFunc):
     pass
 
 
+class ArrayAll(Func):
+    arg_types = {"this": True, "expression": True}
+
+
+class ArrayAny(Func):
+    arg_types = {"this": True, "expression": True}
+
+
 class ArrayContains(Func):
     arg_types = {"this": True, "expression": True}
 
 
+class ArrayFilter(Func):
+    arg_types = {"this": True, "expression": True}
+
+
 class ArraySize(Func):
     pass
 
@@ -1714,6 +1759,10 @@ class Count(AggFunc):
     pass
 
 
+class CurrentDate(Func):
+    arg_types = {"this": False}
+
+
 class DateAdd(Func):
     arg_types = {"this": True, "expression": True, "unit": False}
 
@@ -1726,6 +1775,10 @@ class DateStrToDate(Func):
     pass
 
 
+class DateSub(Func):
+    arg_types = {"this": True, "expression": True, "unit": False}
+
+
 class DateToDateStr(Func):
     pass
 
@@ -1854,6 +1907,10 @@ class Round(Func):
     arg_types = {"this": True, "decimals": False}
 
 
+class SafeDivide(Func):
+    arg_types = {"this": True, "expression": True}
+
+
 class SetAgg(AggFunc):
     pass
 
