@@ -15,23 +15,20 @@ class Parser:
     and produces a parsed syntax tree.
 
     Args
-        functions (dict): the dictionary of additional functions in which the key
-            represents a function's SQL name and the value is a function which constructs
-            the function instance from a list of arguments.
         error_level (ErrorLevel): the desired error level. Default: ErrorLevel.RAISE.
         error_message_context (int): determines the amount of context to capture from
             a query string when displaying the error message (in number of characters).
             Default: 50.
         index_offset (int): Index offset for arrays eg ARRAY[0] vs ARRAY[1] as the head of a list
             Default: 0
-        strict_cast (boolean): if true, cast is expected to raise an error on failure
-            Default: True
     """
 
     FUNCTIONS = {
         name: f.from_arg_list for f in exp.ALL_FUNCTIONS for name in f.sql_names()
     }
 
+    NO_PAREN_FUNCTIONS = {TokenType.CURRENT_DATE: exp.CurrentDate}
+
     TYPE_TOKENS = {
         TokenType.BOOLEAN,
         TokenType.TINYINT,
@@ -56,7 +53,6 @@ class Parser:
 
     NESTED_TYPE_TOKENS = {
         TokenType.ARRAY,
-        TokenType.DATE,
         TokenType.MAP,
     }
 
@@ -115,13 +111,18 @@ class Parser:
     }
 
     FUNC_TOKENS = {
+        TokenType.CURRENT_DATE,
         TokenType.EXTRACT,
+        TokenType.OFFSET,
         TokenType.PRIMARY_KEY,
         TokenType.REPLACE,
         TokenType.UNNEST,
         TokenType.VAR,
         TokenType.LEFT,
         TokenType.RIGHT,
+        TokenType.DATE,
+        TokenType.TIMESTAMP,
+        TokenType.TIMESTAMPTZ,
         *CASTS,
         *NESTED_TYPE_TOKENS,
         *SUBQUERY_PREDICATES,
@@ -135,7 +136,6 @@ class Parser:
     EQUALITY = {
         TokenType.EQ: exp.EQ,
         TokenType.NEQ: exp.NEQ,
-        TokenType.IS: exp.Is,
     }
 
     COMPARISON = {
@@ -189,21 +189,18 @@ class Parser:
         TokenType.CROSS,
     }
 
-    COLUMN_OPERATORS = {
-        TokenType.COLON,
-        TokenType.DOT,
-    }
+    COLUMN_OPERATORS = {TokenType.DOT}
 
     CREATABLES = {TokenType.TABLE, TokenType.VIEW, TokenType.FUNCTION}
 
+    STRICT_CAST = True
+
     __slots__ = (
-        "functions",
         "error_level",
         "error_message_context",
         "sql",
         "errors",
         "index_offset",
-        "strict_cast",
         "_tokens",
         "_chunks",
         "_index",
@@ -214,17 +211,13 @@ class Parser:
 
     def __init__(
         self,
-        functions=None,
         error_level=None,
         error_message_context=100,
         index_offset=0,
-        strict_cast=True,
     ):
-        self.functions = {**self.FUNCTIONS, **(functions or {})}
         self.error_level = error_level or ErrorLevel.RAISE
         self.error_message_context = error_message_context
         self.index_offset = index_offset
-        self.strict_cast = strict_cast
         self.reset()
 
     def reset(self):
@@ -929,7 +922,7 @@ class Parser:
             return None
 
         self._match_l_paren()
-        expressions = self._parse_csv(self._parse_table)
+        expressions = self._parse_csv(self._parse_column)
         self._match_r_paren()
 
         ordinality = self._match(TokenType.WITH) and self._match(TokenType.ORDINALITY)
@@ -1075,20 +1068,26 @@ class Parser:
 
     def _parse_range(self):
         this = self._parse_bitwise()
-
         negate = self._match(TokenType.NOT)
 
-        if self._match(TokenType.LIKE):
+        if self._match(TokenType.IS):
+            negate = self._match(TokenType.NOT)
+            this = self.expression(
+                exp.Is,
+                this=this,
+                expression=self._parse_null() or self._parse_boolean(),
+            )
+        elif self._match(TokenType.LIKE):
             this = self._parse_escape(
-                self.expression(exp.Like, this=this, expression=self._parse_term())
+                self.expression(exp.Like, this=this, expression=self._parse_type())
             )
         elif self._match(TokenType.ILIKE):
             this = self._parse_escape(
-                self.expression(exp.ILike, this=this, expression=self._parse_term())
+                self.expression(exp.ILike, this=this, expression=self._parse_type())
             )
         elif self._match(TokenType.RLIKE):
             this = self.expression(
-                exp.RegexpLike, this=this, expression=self._parse_term()
+                exp.RegexpLike, this=this, expression=self._parse_type()
             )
         elif self._match(TokenType.IN):
             self._match_l_paren()
@@ -1129,7 +1128,7 @@ class Parser:
 
     def _parse_unary(self):
         if self._match(TokenType.NOT):
-            return self.expression(exp.Not, this=self._parse_unary())
+            return self.expression(exp.Not, this=self._parse_equality())
         if self._match(TokenType.TILDA):
             return self.expression(exp.BitwiseNot, this=self._parse_unary())
         if self._match(TokenType.DASH):
@@ -1179,7 +1178,7 @@ class Parser:
                 self._parse_types if nested else self._parse_number
             )
 
-            if nested and not expressions:
+            if not expressions:
                 self._retreat(index)
                 return None
 
@@ -1276,23 +1275,30 @@ class Parser:
         if self._match(TokenType.IF):
             return self._parse_if()
 
-        if (
-            not self._curr
-            or self._curr.token_type not in self.FUNC_TOKENS
-            or not self._next
-            or self._next.token_type != TokenType.L_PAREN
-        ):
+        if not self._curr:
+            return None
+
+        token_type = self._curr.token_type
+
+        if not self._next or self._next.token_type != TokenType.L_PAREN:
+            if token_type in self.NO_PAREN_FUNCTIONS:
+                return self.expression(
+                    self._advance() or self.NO_PAREN_FUNCTIONS[token_type]
+                )
+            return None
+
+        if token_type not in self.FUNC_TOKENS:
             return None
 
         if self._match_set(self.CASTS):
-            strict = self.strict_cast and self._prev.token_type == TokenType.CAST
+            strict = self.STRICT_CAST and token_type == TokenType.CAST
             self._advance()
             this = self._parse_cast(strict)
         elif self._match(TokenType.EXTRACT):
             self._advance()
             this = self._parse_extract()
         else:
-            subquery_predicate = self.SUBQUERY_PREDICATES.get(self._curr.token_type)
+            subquery_predicate = self.SUBQUERY_PREDICATES.get(token_type)
             this = self._curr.text.upper()
             self._advance(2)
 
@@ -1304,7 +1310,7 @@ class Parser:
                 self._match_r_paren()
                 return this
 
-            function = self.functions.get(this)
+            function = self.FUNCTIONS.get(this)
             args = self._parse_csv(self._parse_lambda)
 
             if not callable(function):
@@ -1412,7 +1418,7 @@ class Parser:
 
         expressions = self._parse_csv(self._parse_conjunction)
 
-        if this.text("this").upper() == "ARRAY":
+        if not this or this.text("this").upper() == "ARRAY":
             this = self.expression(exp.Array, expressions=expressions)
         else:
             expressions = apply_index_offset(expressions, -self.index_offset)
@@ -1613,9 +1619,27 @@ class Parser:
 
     def _parse_star(self):
         if self._match(TokenType.STAR):
-            return exp.Star()
+            return self._parse_replace(self._parse_except(exp.Star()))
         return None
 
+    def _parse_except(self, this):
+        if not self._match(TokenType.EXCEPT):
+            return this
+
+        self._match_l_paren()
+        columns = self._parse_csv(self._parse_id_var)
+        self._match_r_paren()
+        return self.expression(exp.StarExcept, this=this, expressions=columns)
+
+    def _parse_replace(self, this):
+        if not self._match(TokenType.REPLACE):
+            return this
+
+        self._match_l_paren()
+        columns = self._parse_csv(lambda: self._parse_alias(self._parse_id_var()))
+        self._match_r_paren()
+        return self.expression(exp.StarReplace, this=this, expressions=columns)
+
     def _parse_csv(self, parse):
         parse_result = parse()
         items = [parse_result] if parse_result is not None else []
